Simple test
------------

Ensure your device works with this simple test.

.. literalinclude:: ../examples/adxl343_simpletest.py
    :caption: examples/adxl343_simpletest.py
    :lines: 5-

Resolution mode settings
-------------------------

Example showing the Resolution mode setting

.. literalinclude:: ../examples/adxl343_resolution_mode.py
    :caption: examples/adxl343_resolution_mode.py
    :lines: 5-

Acceleration range settings
----------------------------

Example showing the Acceleration range setting

.. literalinclude:: ../examples/adxl343_acceleration_range.py
    :caption: examples/adxl343_acceleration_range.py
    :lines: 5-

Single tap mode settings
-------------------------

Example showing the Single tap mode setting

.. literalinclude:: ../examples/adxl343_single_tap_mode.py
    :caption: examples/adxl343_single_tap_mode.py
    :lines: 5-

Double tap mode settings
-------------------------

Example showing the Double tap mode setting

.. literalinclude:: ../examples/adxl343_double_tap_mode.py
    :caption: examples/adxl343_double_tap_mode.py
    :lines: 5-

Activity Detection
-------------------------

Example showing an activity detection example

.. literalinclude:: ../examples/adxl343_activity_detection.py
    :caption: examples/adxl343_activity_detection.py
    :lines: 5-

Inactivity Detection
-------------------------

Example showing an inactivity detection example

.. literalinclude:: ../examples/adxl343_inactivity_detection.py
    :caption: examples/adxl343_inactivity_detection.py
    :lines: 5-
